@@ -1,12 +1,15 @@
 angular.module('opal.services')
     .factory('episodeLoader', function($q, $route,
                                            EpisodeResource,
-                                           Episode, detailSchemaLoader) {
-    return function() {
+                                           Episode, recordLoader) {
+    return function(episode_id) {
+        if(!episode_id){
+            episode_id = $route.current.params.id;
+        }
 	    var deferred = $q.defer();
-	    detailSchemaLoader.then(function(schema) {
-	        EpisodeResource.get({id: $route.current.params.id}, function(resource) {
-		        var episode = new Episode(resource, schema);
+	    recordLoader.load().then(function(records) {
+	        EpisodeResource.get({id: episode_id}, function(resource) {
+		        var episode = new Episode(resource);
 		        deferred.resolve(episode);
 	        }, function() {
 		        // handle error better
